﻿// =================================================================================================
// Copyright © Quorum Business Solutions, Inc. 2008-2014.  All Rights Reserved.
// =================================================================================================

#region Using Statements
using System.ComponentModel;
#endregion

namespace GridRowDelete.Data
{
    public class ColTopMovie : QTRMBindingList<TopMovie>
    {
        #region Private Members
        private bool m_TrackChanges;
        #endregion

        #region Properties
        public bool TrackChanges
        {
            get { return m_TrackChanges; }
            set
            {
                m_TrackChanges = value;
            }
        }
        #endregion

        #region Constructors
        public ColTopMovie()
        {
            this.TrackChanges = false;
            this.ListChanged += OnListChanged;
            this.Removing += OnRemovingItem;
        }
        #endregion

        #region OnListChanged
        void OnListChanged(object sender, ListChangedEventArgs e)
        {
            if (!this.TrackChanges)
            {
                return;
            }

            if ((e.PropertyDescriptor != null) && (!string.IsNullOrEmpty(e.PropertyDescriptor.Name)) && (e.PropertyDescriptor.Name == "Dirty"))
            {
                return;
            }

            if (e.ListChangedType == ListChangedType.ItemChanged)
            {
                if (this.Items[e.NewIndex].Dirty == ChangeStatus.NoChange)
                {
                    this.Items[e.NewIndex].Dirty = ChangeStatus.Modified;
                }
            }
            else if (e.ListChangedType == ListChangedType.ItemAdded)
            {
                this.Items[e.NewIndex].Dirty = ChangeStatus.Inserted;
            }
        }
        #endregion

        #region OnRemovingItem
        void OnRemovingItem(object sender, QTRMListChangedEventArgs e)
        {
            if (!this.TrackChanges)
            {
                return;
            }

            if (this.Items[e.NewIndex].Dirty != ChangeStatus.Inserted)
            {
                this.Items[e.NewIndex].Dirty = ChangeStatus.Deleted;
                e.Cancel = true;
            }
        }
        #endregion
    }
}
